==> zio-aws-mediapackage_3-5.17.190.2-sources.jar: zio/aws/mediapackage/model/CmafEncryption.scala <==
package zio.aws.mediapackage.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import zio.aws.mediapackage.model.primitives.{__integer, __string}
import scala.jdk.CollectionConverters.*
final case class CmafEncryption(
    constantInitializationVector: Optional[__string] = Optional.Absent,
    keyRotationIntervalSeconds: Optional[__integer] = Optional.Absent,
    spekeKeyProvider: zio.aws.mediapackage.model.SpekeKeyProvider
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.CmafEncryption = {
    import CmafEncryption.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.CmafEncryption
      .builder()
      .optionallyWith(
        constantInitializationVector.map(value => value: java.lang.String)
      )(_.constantInitializationVector)
      .optionallyWith(keyRotationIntervalSeconds.map(value => value: Integer))(
        _.keyRotationIntervalSeconds
      )
      .spekeKeyProvider(spekeKeyProvider.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.mediapackage.model.CmafEncryption.ReadOnly =
    zio.aws.mediapackage.model.CmafEncryption.wrap(buildAwsValue())
}
object CmafEncryption {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.CmafEncryption
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.CmafEncryption =
      zio.aws.mediapackage.model.CmafEncryption(
        constantInitializationVector.map(value => value),
        keyRotationIntervalSeconds.map(value => value),
        spekeKeyProvider.asEditable
      )
    def constantInitializationVector: Optional[__string]
    def keyRotationIntervalSeconds: Optional[__integer]
    def spekeKeyProvider: zio.aws.mediapackage.model.SpekeKeyProvider.ReadOnly
    def getConstantInitializationVector: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField(
        "constantInitializationVector",
        constantInitializationVector
      )
    def getKeyRotationIntervalSeconds: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField(
        "keyRotationIntervalSeconds",
        keyRotationIntervalSeconds
      )
    def getSpekeKeyProvider: ZIO[
      Any,
      Nothing,
      zio.aws.mediapackage.model.SpekeKeyProvider.ReadOnly
    ] = ZIO.succeed(spekeKeyProvider)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.CmafEncryption
  ) extends zio.aws.mediapackage.model.CmafEncryption.ReadOnly {
    override val constantInitializationVector: Optional[__string] =
      zio.aws.core.internal
        .optionalFromNullable(impl.constantInitializationVector())
        .map(value => value: __string)
    override val keyRotationIntervalSeconds: Optional[__integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.keyRotationIntervalSeconds())
        .map(value => value: __integer)
    override val spekeKeyProvider
        : zio.aws.mediapackage.model.SpekeKeyProvider.ReadOnly =
      zio.aws.mediapackage.model.SpekeKeyProvider.wrap(impl.spekeKeyProvider())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.CmafEncryption
  ): zio.aws.mediapackage.model.CmafEncryption.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediapackage_3-6.20.42.2-sources.jar: zio/aws/mediapackage/model/CmafEncryption.scala <==
package zio.aws.mediapackage.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import zio.aws.mediapackage.model.primitives.{__integer, __string}
import scala.jdk.CollectionConverters.*
final case class CmafEncryption(
    constantInitializationVector: Optional[__string] = Optional.Absent,
    encryptionMethod: Optional[
      zio.aws.mediapackage.model.CmafEncryptionMethod
    ] = Optional.Absent,
    keyRotationIntervalSeconds: Optional[__integer] = Optional.Absent,
    spekeKeyProvider: zio.aws.mediapackage.model.SpekeKeyProvider
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.CmafEncryption = {
    import CmafEncryption.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.CmafEncryption
      .builder()
      .optionallyWith(
        constantInitializationVector.map(value => value: java.lang.String)
      )(_.constantInitializationVector)
      .optionallyWith(encryptionMethod.map(value => value.unwrap))(
        _.encryptionMethod
      )
      .optionallyWith(keyRotationIntervalSeconds.map(value => value: Integer))(
        _.keyRotationIntervalSeconds
      )
      .spekeKeyProvider(spekeKeyProvider.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.mediapackage.model.CmafEncryption.ReadOnly =
    zio.aws.mediapackage.model.CmafEncryption.wrap(buildAwsValue())
}
object CmafEncryption {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.CmafEncryption
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.CmafEncryption =
      zio.aws.mediapackage.model.CmafEncryption(
        constantInitializationVector.map(value => value),
        encryptionMethod.map(value => value),
        keyRotationIntervalSeconds.map(value => value),
        spekeKeyProvider.asEditable
      )
    def constantInitializationVector: Optional[__string]
    def encryptionMethod
        : Optional[zio.aws.mediapackage.model.CmafEncryptionMethod]
    def keyRotationIntervalSeconds: Optional[__integer]
    def spekeKeyProvider: zio.aws.mediapackage.model.SpekeKeyProvider.ReadOnly
    def getConstantInitializationVector: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField(
        "constantInitializationVector",
        constantInitializationVector
      )
    def getEncryptionMethod
        : ZIO[Any, AwsError, zio.aws.mediapackage.model.CmafEncryptionMethod] =
      AwsError.unwrapOptionField("encryptionMethod", encryptionMethod)
    def getKeyRotationIntervalSeconds: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField(
        "keyRotationIntervalSeconds",
        keyRotationIntervalSeconds
      )
    def getSpekeKeyProvider: ZIO[
      Any,
      Nothing,
      zio.aws.mediapackage.model.SpekeKeyProvider.ReadOnly
    ] = ZIO.succeed(spekeKeyProvider)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.CmafEncryption
  ) extends zio.aws.mediapackage.model.CmafEncryption.ReadOnly {
    override val constantInitializationVector: Optional[__string] =
      zio.aws.core.internal
        .optionalFromNullable(impl.constantInitializationVector())
        .map(value => value: __string)
    override val encryptionMethod
        : Optional[zio.aws.mediapackage.model.CmafEncryptionMethod] =
      zio.aws.core.internal
        .optionalFromNullable(impl.encryptionMethod())
        .map(value =>
          zio.aws.mediapackage.model.CmafEncryptionMethod.wrap(value)
        )
    override val keyRotationIntervalSeconds: Optional[__integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.keyRotationIntervalSeconds())
        .map(value => value: __integer)
    override val spekeKeyProvider
        : zio.aws.mediapackage.model.SpekeKeyProvider.ReadOnly =
      zio.aws.mediapackage.model.SpekeKeyProvider.wrap(impl.spekeKeyProvider())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.CmafEncryption
  ): zio.aws.mediapackage.model.CmafEncryption.ReadOnly = new Wrapper(impl)
}
